@@ -19,9 +19,7 @@ class SearchListWithButton(SearchList):
     def process(self):
         for uid, run in self.active.selection_as_catalog.items():
             # Pretend to kick off data processing or something.
-            print(
-                f"Processing Run {uid[:8]} (scan_id={run.metadata['start']['scan_id']})"
-            )
+            print(f"Processing Run {uid[:8]} (scan_id={run.metadata['start']['scan_id']})")
 
 
 class QtSearchListWithButton(QWidget):
