@@ -74,6 +74,13 @@ class RunEngineClient:
         self.qserver_custom_module_name = None
         # List of spreadsheet data types
         self.plan_spreadsheet_data_types = None
+        # Dictionary of additional parameters: key - parameter name, value - a dictionary with
+        #   the following key/value pairs: "text" - text description of the parameter to use in the form,
+        #   "values" -  a list or a tuple of values, "type" - type of the value.
+        self.plan_spreadsheet_additional_parameters = {}
+
+        # Indicates if operation of destroying an environment is activated.
+        self._env_destroy_activated = False
 
         # TODO: in the future the list of allowed instructions should be requested from the server
         self._allowed_instructions = {
@@ -410,7 +417,7 @@ class RunEngineClient:
         try:
             key_seq = self._map_column_labels_to_keys[label]
         except KeyError:
-            raise KeyError("Label 'label' is not found in the map dictionary")
+            raise KeyError(f"Label '{label}' is not found in the map dictionary")
 
         # Follow the path in the dictionary. 'KeyError' exception is raised if a key does not exist
         try:
@@ -816,7 +823,8 @@ class RunEngineClient:
                 )
             self.selected_queue_item_uids = sel_item_uids
 
-    def queue_upload_spreadsheet(self, *, file_path, data_type=None):
+    def queue_upload_spreadsheet(self, *, file_path, data_type=None, **kwargs):
+        # ``kwargs``` are passed to the custom spreadsheet processing function
         # TODO: significant part of this function is duplication of the code from
         #   ``bluesky_queueserver.server.server``. Implement reusable function as part of
         #   Queue Server API.
@@ -828,6 +836,7 @@ class RunEngineClient:
         with open(file_path, "rb") as f:
             custom_code_module_name = self.qserver_custom_module_name
 
+            custom_code_module = None
             if custom_code_module_name:
                 try:
                     print(f"Importing custom module '{custom_code_module_name}' ...")
@@ -836,7 +845,6 @@ class RunEngineClient:
                     print(f"Module '{custom_code_module_name}' was imported successfully.")
                     # logger.info("Module '%s' was imported successfully.", custom_code_module_name)
                 except Exception as ex:
-                    custom_code_module = None
                     print(f"Failed to import custom instrument module '{custom_code_module_name}': {ex}")
                     # logger.error("Failed to import custom instrument module '%s':
                     # %s", custom_code_module_name, ex)
@@ -849,7 +857,7 @@ class RunEngineClient:
                 # Try applying  the custom processing function. Some additional useful data is passed to
                 #   the function. Unnecessary parameters can be ignored.
                 item_list = custom_code_module.spreadsheet_to_plan_list(
-                    spreadsheet_file=f, file_name=f_name, data_type=data_type, user=self._user_name
+                    spreadsheet_file=f, file_name=f_name, data_type=data_type, user=self._user_name, **kwargs
                 )
                 # The function is expected to return None if it rejects the file (based on 'data_type').
                 #   Then try to apply the default processing function.
@@ -984,14 +992,16 @@ class RunEngineClient:
         # Wait for the environment to be created.
         if timeout:
             t_stop = time.time() + timeout
-        while True:
-            self.load_re_manager_status()
-            status2 = self._re_manager_status
-            if status2["worker_environment_exists"] and status2["manager_state"] == "idle":
-                break
-            if timeout and (time.time() > t_stop):
-                raise RuntimeError("Failed to start RE Worker: timeout occurred")
-            time.sleep(0.5)
+            while True:
+                self.load_re_manager_status()
+                status2 = self._re_manager_status
+                if status2["worker_environment_exists"] and status2["manager_state"] == "idle":
+                    break
+                if timeout and (time.time() > t_stop):
+                    raise RuntimeError("Failed to start RE Worker: timeout occurred")
+                time.sleep(0.5)
+
+        self.activate_env_destroy(False)
 
     def environment_close(self, timeout=0):
         """
@@ -1033,6 +1043,19 @@ class RunEngineClient:
                 raise RuntimeError("Failed to start RE Worker: timeout occurred")
             time.sleep(0.5)
 
+        self.activate_env_destroy(False)
+
+    @property
+    def env_destroy_activated(self):
+        return self._env_destroy_activated
+
+    def activate_env_destroy(self, state):
+        self._env_destroy_activated = bool(state)
+        self.events.status_changed(
+            status=self._re_manager_status,
+            is_connected=self._re_manager_connected,
+        )
+
     def environment_destroy(self, timeout=0):
         """
         Destroy (unresponsive) RE Worker environment. The function is intended for the cases when
@@ -1050,6 +1073,9 @@ class RunEngineClient:
         -------
         None
         """
+        if not self._env_destroy_activated:
+            raise RuntimeError("'Destroy Environment' operation is not activated and can not be executed")
+
         # Check if RE Worker environment already exists and RE manager is idle.
         self.load_re_manager_status()
         status = self._re_manager_status
@@ -1073,6 +1099,8 @@ class RunEngineClient:
                 raise RuntimeError("Failed to start RE Worker: timeout occurred")
             time.sleep(0.5)
 
+        self.activate_env_destroy(False)
+
     # ============================================================================
     #                        Queue Control
 
